@@ -731,6 +731,8 @@ PR_YPOS = PROP_TAG( PT_LONG,      0x3F06)
 PR_CONTROL_ID = PROP_TAG( PT_BINARY,    0x3F07)
 PR_INITIAL_DETAILS_PANE = PROP_TAG( PT_LONG,      0x3F08)
 
+PR_PROCESSED		= PROP_TAG(PT_BOOLEAN, 0x7D01)
+
 PROP_ID_SECURE_MIN	= 0x67F0
 PT_FILE_HANDLE		= 0x0103
 PT_FILE_EA			= 0x0104
@@ -1388,6 +1390,7 @@ PR_EC_STORETYPE             = PROP_TAG(PT_LONG,               PR_EC_BASE+0x14)
 PR_EC_PARENT_HIERARCHYID    = PROP_TAG(PT_LONG,               PR_EC_BASE+0x15)
 PR_EC_PARENT_CHANGE_KEY     = PROP_TAG(PT_BINARY,             PR_EC_BASE+0x16)
 PR_EC_PACKED_NAME_PROPS     = PROP_TAG(PT_BINARY,             PR_EC_BASE+0x17)
+PR_EC_QUOTA_MAIL_TIME       = PROP_TAG(PT_SYSTIME,            PR_EC_BASE+0x20)
 
 PR_ZC_CONTACT_STORE_ENTRYIDS =	PROP_TAG(PT_MV_BINARY,  PR_EC_BASE + 0x11)
 PR_ZC_CONTACT_FOLDER_ENTRYIDS =	PROP_TAG(PT_MV_BINARY,  PR_EC_BASE + 0x12)
@@ -1424,6 +1427,17 @@ PR_EC_STATS_SESSION_PORT	= 	PROP_TAG(PT_LONG,               PR_EC_BASE+0x48)
 PR_EC_STATS_SESSION_URL     = 	PROP_TAG(PT_STRING8,    PR_EC_BASE+0x52)
 PR_EC_STATS_SESSION_PROXY   = 	PROP_TAG(PT_STRING8,    PR_EC_BASE+0x53)
 
+# user stats
+PR_EC_STATS_SESSION_PROCSTATES = PROP_TAG(PT_MV_STRING8,	PR_EC_BASE+0x49)
+PR_EC_STATS_SESSION_CPU_USER =	PROP_TAG(PT_DOUBLE,		PR_EC_BASE+0x4a)
+PR_EC_STATS_SESSION_CPU_SYSTEM = PROP_TAG(PT_DOUBLE,		PR_EC_BASE+0x4b)
+PR_EC_STATS_SESSION_CPU_REAL =	PROP_TAG(PT_DOUBLE,		PR_EC_BASE+0x4c)
+PR_EC_STATS_SESSION_GROUP_ID = PROP_TAG(PT_LONGLONG,	PR_EC_BASE+0x4d)
+PR_EC_STATS_SESSION_PEER_PID = PROP_TAG(PT_LONG,		PR_EC_BASE+0x4e)
+PR_EC_STATS_SESSION_CLIENT_VERSION =	PROP_TAG(PT_STRING8,	PR_EC_BASE+0x4f)
+PR_EC_STATS_SESSION_CLIENT_APPLICATION = PROP_TAG(PT_STRING8, PR_EC_BASE+0x50)
+PR_EC_STATS_SESSION_REQUESTS =	PROP_TAG(PT_LONG, 		PR_EC_BASE+0x51)
+
 PR_EC_COMPANY_NAME =            PROP_TAG(PT_TSTRING,    PR_EC_BASE+0x48)
 PR_EC_COMPANY_NAME_A =          PROP_TAG(PT_STRING8,    PR_EC_BASE+0x48)
 PR_EC_COMPANY_NAME_W =          PROP_TAG(PT_UNICODE,    PR_EC_BASE+0x48)
@@ -1431,6 +1445,13 @@ PR_EC_COMPANY_ADMIN =           PROP_TAG(PT_TSTRING,    PR_EC_BASE+0x49)
 PR_EC_COMPANY_ADMIN_A =         PROP_TAG(PT_STRING8,    PR_EC_BASE+0x49)
 PR_EC_COMPANY_ADMIN_W =         PROP_TAG(PT_UNICODE,    PR_EC_BASE+0x49)
 
+PR_EC_OUTOFOFFICE                   = PROP_TAG(PT_BOOLEAN,    PR_EC_BASE+0x60)
+PR_EC_OUTOFOFFICE_MSG               = PROP_TAG(PT_TSTRING,    PR_EC_BASE+0x61)
+PR_EC_OUTOFOFFICE_SUBJECT           = PROP_TAG(PT_TSTRING,    PR_EC_BASE+0x62)
+
+PR_EC_STATS_SESSION_CLIENT_APPLICATION_VERSION = PROP_TAG(PT_STRING8, PR_EC_BASE+0x54)
+PR_EC_STATS_SESSION_CLIENT_APPLICATION_MISC    = PROP_TAG(PT_STRING8, PR_EC_BASE+0x55)
+
 PR_EC_STATS_SERVER_NAME =		PROP_TAG(PT_STRING8,	PR_EC_BASE+0xF0)
 PR_EC_STATS_SERVER_HOST	= 		PROP_TAG(PT_STRING8,	PR_EC_BASE+0xF1)
 PR_EC_STATS_SERVER_HTTPPORT	=	PROP_TAG(PT_LONG,		PR_EC_BASE+0xF2)
@@ -1483,6 +1504,10 @@ EC_PROFILE_FLAGS_CACHE_PUBLIC			= 0x0000400
 EC_PROFILE_FLAGS_TRUNCATE_SOURCEKEY		= 0x0000800
 EC_PROFILE_FLAGS_NO_UID_AUTH			= 0x0001000
 
+# WebAccess / WebApp settings
+PR_EC_WEBACCESS_SETTINGS = PROP_TAG(PT_STRING8, PR_EC_BASE+0x70)
+PR_EC_WEBAPP_SETTINGS_JSON = PROP_TAG(PT_STRING8, PR_EC_BASE+0x72)
+
 # Flags for PurgeCache
 PURGE_CACHE_QUOTA			= 0x0001
 PURGE_CACHE_QUOTADEFAULT	= 0x0002
@@ -1649,6 +1674,11 @@ ecRightsFolderAccess    = 0x00000100
 ecRightsFolderVisible   = 0x00000400
 ecRightsFullControl     = 0x00004FBL
 
+ecRightsTemplateNoRights    = ecRightsFolderVisible
+ecRightsTemplateReadOnly    = ecRightsTemplateNoRights | ecRightsReadAny
+ecRightsTemplateSecretary   = ecRightsTemplateReadOnly | ecRightsCreate | ecRightsEditOwned | ecRightsDeleteOwned | ecRightsEditAny | ecRightsDeleteAny
+ecRightsTemplateOwner       = ecRightsTemplateSecretary | ecRightsCreateSubfolder | ecRightsFolderAccess
+
 EMS_AB_ADDRESS_LOOKUP = 0x1
 
 SHOW_SOFT_DELETES	= 0x02
@@ -1660,3 +1690,25 @@ DTE_MASK_REMOTE       = 0x0000ff00
 DTE_MASK_LOCAL        = 0x000000ff
 
 EC_TABLE_NOCAP        = 0x40000000
+
+
+# ENUMS
+
+respNone            = 0x00000000
+respOrganized       = 0x00000001
+respTentative       = 0x00000002
+respAccepted        = 0x00000003
+respDeclined        = 0x00000004
+respNotResponded    = 0x00000005
+
+ICON_APPT_APPOINTMENT               = 0x00000400
+ICON_APPT_RECURRING             = 0x00000401
+ICON_APPT_MEETING_SINGLE        = 0x00000402
+ICON_APPT_MEETING_RECURRING         = 0x00000403
+ICON_APPT_MEETING_REQUEST           = 0x00000404
+ICON_APPT_MEETING_ACCEPT            = 0x00000405
+ICON_APPT_MEETING_DECLINE           = 0x00000406
+ICON_APPT_MEETING_TENTATIVE         = 0x00000407
+ICON_APPT_MEETING_CANCEL            = 0x00000408
+ICON_APPT_MEETING_UPDATE            = 0x00000409
+ICON_APPT_MEETING_FORWARD           = 0x0000040b
